# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class ObjectTypeDefinitionPatch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "secondary_display_properties": "list[str]",
        "required_properties": "list[str]",
        "searchable_properties": "list[str]",
        "clear_description": "bool",
        "primary_display_property": "str",
        "description": "str",
        "restorable": "bool",
        "labels": "ObjectTypeDefinitionLabels",
    }

    attribute_map = {
        "secondary_display_properties": "secondaryDisplayProperties",
        "required_properties": "requiredProperties",
        "searchable_properties": "searchableProperties",
        "clear_description": "clearDescription",
        "primary_display_property": "primaryDisplayProperty",
        "description": "description",
        "restorable": "restorable",
        "labels": "labels",
    }

    def __init__(
        self,
        secondary_display_properties=None,
        required_properties=None,
        searchable_properties=None,
        clear_description=None,
        primary_display_property=None,
        description=None,
        restorable=None,
        labels=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ObjectTypeDefinitionPatch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._secondary_display_properties = None
        self._required_properties = None
        self._searchable_properties = None
        self._clear_description = None
        self._primary_display_property = None
        self._description = None
        self._restorable = None
        self._labels = None
        self.discriminator = None

        if secondary_display_properties is not None:
            self.secondary_display_properties = secondary_display_properties
        if required_properties is not None:
            self.required_properties = required_properties
        if searchable_properties is not None:
            self.searchable_properties = searchable_properties
        if clear_description is not None:
            self.clear_description = clear_description
        if primary_display_property is not None:
            self.primary_display_property = primary_display_property
        if description is not None:
            self.description = description
        if restorable is not None:
            self.restorable = restorable
        if labels is not None:
            self.labels = labels

    @property
    def secondary_display_properties(self):
        """Gets the secondary_display_properties of this ObjectTypeDefinitionPatch.  # noqa: E501

        The names of secondary properties for this object. These will be displayed as secondary on the HubSpot record page for this object type.  # noqa: E501

        :return: The secondary_display_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._secondary_display_properties

    @secondary_display_properties.setter
    def secondary_display_properties(self, secondary_display_properties):
        """Sets the secondary_display_properties of this ObjectTypeDefinitionPatch.

        The names of secondary properties for this object. These will be displayed as secondary on the HubSpot record page for this object type.  # noqa: E501

        :param secondary_display_properties: The secondary_display_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type secondary_display_properties: list[str]
        """

        self._secondary_display_properties = secondary_display_properties

    @property
    def required_properties(self):
        """Gets the required_properties of this ObjectTypeDefinitionPatch.  # noqa: E501

        The names of properties that should be **required** when creating an object of this type.  # noqa: E501

        :return: The required_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._required_properties

    @required_properties.setter
    def required_properties(self, required_properties):
        """Sets the required_properties of this ObjectTypeDefinitionPatch.

        The names of properties that should be **required** when creating an object of this type.  # noqa: E501

        :param required_properties: The required_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type required_properties: list[str]
        """

        self._required_properties = required_properties

    @property
    def searchable_properties(self):
        """Gets the searchable_properties of this ObjectTypeDefinitionPatch.  # noqa: E501

        Names of properties that will be indexed for this object type in by HubSpot's product search.  # noqa: E501

        :return: The searchable_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._searchable_properties

    @searchable_properties.setter
    def searchable_properties(self, searchable_properties):
        """Sets the searchable_properties of this ObjectTypeDefinitionPatch.

        Names of properties that will be indexed for this object type in by HubSpot's product search.  # noqa: E501

        :param searchable_properties: The searchable_properties of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type searchable_properties: list[str]
        """

        self._searchable_properties = searchable_properties

    @property
    def clear_description(self):
        """Gets the clear_description of this ObjectTypeDefinitionPatch.  # noqa: E501


        :return: The clear_description of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: bool
        """
        return self._clear_description

    @clear_description.setter
    def clear_description(self, clear_description):
        """Sets the clear_description of this ObjectTypeDefinitionPatch.


        :param clear_description: The clear_description of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type clear_description: bool
        """

        self._clear_description = clear_description

    @property
    def primary_display_property(self):
        """Gets the primary_display_property of this ObjectTypeDefinitionPatch.  # noqa: E501

        The name of the primary property for this object. This will be displayed as primary on the HubSpot record page for this object type.  # noqa: E501

        :return: The primary_display_property of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: str
        """
        return self._primary_display_property

    @primary_display_property.setter
    def primary_display_property(self, primary_display_property):
        """Sets the primary_display_property of this ObjectTypeDefinitionPatch.

        The name of the primary property for this object. This will be displayed as primary on the HubSpot record page for this object type.  # noqa: E501

        :param primary_display_property: The primary_display_property of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type primary_display_property: str
        """

        self._primary_display_property = primary_display_property

    @property
    def description(self):
        """Gets the description of this ObjectTypeDefinitionPatch.  # noqa: E501


        :return: The description of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ObjectTypeDefinitionPatch.


        :param description: The description of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def restorable(self):
        """Gets the restorable of this ObjectTypeDefinitionPatch.  # noqa: E501


        :return: The restorable of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: bool
        """
        return self._restorable

    @restorable.setter
    def restorable(self, restorable):
        """Sets the restorable of this ObjectTypeDefinitionPatch.


        :param restorable: The restorable of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type restorable: bool
        """

        self._restorable = restorable

    @property
    def labels(self):
        """Gets the labels of this ObjectTypeDefinitionPatch.  # noqa: E501


        :return: The labels of this ObjectTypeDefinitionPatch.  # noqa: E501
        :rtype: ObjectTypeDefinitionLabels
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this ObjectTypeDefinitionPatch.


        :param labels: The labels of this ObjectTypeDefinitionPatch.  # noqa: E501
        :type labels: ObjectTypeDefinitionLabels
        """

        self._labels = labels

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectTypeDefinitionPatch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectTypeDefinitionPatch):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Associations

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.api.batch_api import BatchApi

# import ApiClient
from hubspot.crm.associations.api_client import ApiClient
from hubspot.crm.associations.configuration import Configuration
from hubspot.crm.associations.exceptions import OpenApiException
from hubspot.crm.associations.exceptions import ApiTypeError
from hubspot.crm.associations.exceptions import ApiValueError
from hubspot.crm.associations.exceptions import ApiKeyError
from hubspot.crm.associations.exceptions import ApiAttributeError
from hubspot.crm.associations.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.models.associated_id import AssociatedId
from hubspot.crm.associations.models.batch_input_public_association import BatchInputPublicAssociation
from hubspot.crm.associations.models.batch_input_public_object_id import BatchInputPublicObjectId
from hubspot.crm.associations.models.batch_response_public_association import BatchResponsePublicAssociation
from hubspot.crm.associations.models.batch_response_public_association_multi import BatchResponsePublicAssociationMulti
from hubspot.crm.associations.models.batch_response_public_association_multi_with_errors import BatchResponsePublicAssociationMultiWithErrors
from hubspot.crm.associations.models.batch_response_public_association_with_errors import BatchResponsePublicAssociationWithErrors
from hubspot.crm.associations.models.error import Error
from hubspot.crm.associations.models.error_detail import ErrorDetail
from hubspot.crm.associations.models.next_page import NextPage
from hubspot.crm.associations.models.paging import Paging
from hubspot.crm.associations.models.previous_page import PreviousPage
from hubspot.crm.associations.models.public_association import PublicAssociation
from hubspot.crm.associations.models.public_association_multi import PublicAssociationMulti
from hubspot.crm.associations.models.public_object_id import PublicObjectId
from hubspot.crm.associations.models.standard_error import StandardError



# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.files.api_client import ApiClient
from hubspot.files.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class FoldersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, folder_id, **kwargs):  # noqa: E501
        """Delete folder by ID  # noqa: E501

        Delete folder by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of folder to delete. (required)
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(folder_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Delete folder by ID  # noqa: E501

        Delete folder by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of folder to delete. (required)
        :type folder_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["folder_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `archive`")  # noqa: E501

        if self.api_client.client_side_validation and "folder_id" in local_var_params and not re.search(r"\d+", local_var_params["folder_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `folder_id` when calling `archive`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/files/v3/folders/{folderId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def archive_by_path(self, folder_path, **kwargs):  # noqa: E501
        """Delete folder by path  # noqa: E501

        Delete a folder, identified by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_by_path(folder_path, async_req=True)
        >>> result = thread.get()

        :param folder_path: Path of folder to delete (required)
        :type folder_path: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_by_path_with_http_info(folder_path, **kwargs)  # noqa: E501

    def archive_by_path_with_http_info(self, folder_path, **kwargs):  # noqa: E501
        """Delete folder by path  # noqa: E501

        Delete a folder, identified by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_by_path_with_http_info(folder_path, async_req=True)
        >>> result = thread.get()

        :param folder_path: Path of folder to delete (required)
        :type folder_path: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["folder_path"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive_by_path" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_path' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_path") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_path` when calling `archive_by_path`")  # noqa: E501

        if self.api_client.client_side_validation and "folder_path" in local_var_params and not re.search(r".+", local_var_params["folder_path"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `folder_path` when calling `archive_by_path`, must conform to the pattern `/.+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "folder_path" in local_var_params:
            path_params["folderPath"] = local_var_params["folder_path"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/files/v3/folders/{folderPath}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def check_update_status(self, task_id, **kwargs):  # noqa: E501
        """Check folder update status  # noqa: E501

        Check status of folder update. Folder updates happen asynchronously.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.check_update_status(task_id, async_req=True)
        >>> result = thread.get()

        :param task_id: The ID of the folder update task. (required)
        :type task_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: FolderActionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.check_update_status_with_http_info(task_id, **kwargs)  # noqa: E501

    def check_update_status_with_http_info(self, task_id, **kwargs):  # noqa: E501
        """Check folder update status  # noqa: E501

        Check status of folder update. Folder updates happen asynchronously.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.check_update_status_with_http_info(task_id, async_req=True)
        >>> result = thread.get()

        :param task_id: The ID of the folder update task. (required)
        :type task_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(FolderActionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["task_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method check_update_status" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'task_id' is set
        if self.api_client.client_side_validation and local_var_params.get("task_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_id` when calling `check_update_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "task_id" in local_var_params:
            path_params["taskId"] = local_var_params["task_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "FolderActionResponse",
        }

        return self.api_client.call_api(
            "/files/v3/folders/update/async/tasks/{taskId}/status",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, folder_input, **kwargs):  # noqa: E501
        """Create folder  # noqa: E501

        Creates a folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(folder_input, async_req=True)
        >>> result = thread.get()

        :param folder_input: Folder creation options (required)
        :type folder_input: FolderInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Folder
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(folder_input, **kwargs)  # noqa: E501

    def create_with_http_info(self, folder_input, **kwargs):  # noqa: E501
        """Create folder  # noqa: E501

        Creates a folder.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(folder_input, async_req=True)
        >>> result = thread.get()

        :param folder_input: Folder creation options (required)
        :type folder_input: FolderInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Folder, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_input' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_input` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "folder_input" in local_var_params:
            body_params = local_var_params["folder_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "Folder",
        }

        return self.api_client.call_api(
            "/files/v3/folders",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def do_search(self, **kwargs):  # noqa: E501
        """Search folders  # noqa: E501

        Search for folders. Does not contain hidden or archived folders.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search(async_req=True)
        >>> result = thread.get()

        :param properties: Properties that should be included in the returned folders.
        :type properties: list[str]
        :param after: Offset search results by this value. The default offset is 0 and the maximum offset of items for a given search is 10,000. Narrow your search down if you are reaching this limit.
        :type after: str
        :param before:
        :type before: str
        :param limit: Number of items to return. Default limit is 10, maximum limit is 100.
        :type limit: int
        :param sort: Sort results by given property. For example -name sorts by name field descending, name sorts by name field ascending.
        :type sort: list[str]
        :param ids:
        :type ids: list[int]
        :param id_lte:
        :type id_lte: int
        :param id_gte:
        :type id_gte: int
        :param created_at: Search folders by exact time of creation. Time must be epoch time in milliseconds.
        :type created_at: datetime
        :param created_at_lte: Search folders by less than or equal to time of creation. Can be used with createdAtGte to create a range.
        :type created_at_lte: datetime
        :param created_at_gte: Search folders by greater than or equal to time of creation. Can be used with createdAtLte to create a range.
        :type created_at_gte: datetime
        :param updated_at: Search folders by exact time of latest updated. Time must be epoch time in milliseconds.
        :type updated_at: datetime
        :param updated_at_lte: Search folders by less than or equal to time of latest update. Can be used with updatedAtGte to create a range.
        :type updated_at_lte: datetime
        :param updated_at_gte: Search folders by greater than or equal to time of latest update. Can be used with updatedAtLte to create a range.
        :type updated_at_gte: datetime
        :param name: Search for folders containing the specified name.
        :type name: str
        :param path: Search folders by path.
        :type path: str
        :param parent_folder_ids: Search folders with the given parent folderId.
        :type parent_folder_ids: list[int]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseFolder
        """
        kwargs["_return_http_data_only"] = True
        return self.do_search_with_http_info(**kwargs)  # noqa: E501

    def do_search_with_http_info(self, **kwargs):  # noqa: E501
        """Search folders  # noqa: E501

        Search for folders. Does not contain hidden or archived folders.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param properties: Properties that should be included in the returned folders.
        :type properties: list[str]
        :param after: Offset search results by this value. The default offset is 0 and the maximum offset of items for a given search is 10,000. Narrow your search down if you are reaching this limit.
        :type after: str
        :param before:
        :type before: str
        :param limit: Number of items to return. Default limit is 10, maximum limit is 100.
        :type limit: int
        :param sort: Sort results by given property. For example -name sorts by name field descending, name sorts by name field ascending.
        :type sort: list[str]
        :param ids:
        :type ids: list[int]
        :param id_lte:
        :type id_lte: int
        :param id_gte:
        :type id_gte: int
        :param created_at: Search folders by exact time of creation. Time must be epoch time in milliseconds.
        :type created_at: datetime
        :param created_at_lte: Search folders by less than or equal to time of creation. Can be used with createdAtGte to create a range.
        :type created_at_lte: datetime
        :param created_at_gte: Search folders by greater than or equal to time of creation. Can be used with createdAtLte to create a range.
        :type created_at_gte: datetime
        :param updated_at: Search folders by exact time of latest updated. Time must be epoch time in milliseconds.
        :type updated_at: datetime
        :param updated_at_lte: Search folders by less than or equal to time of latest update. Can be used with updatedAtGte to create a range.
        :type updated_at_lte: datetime
        :param updated_at_gte: Search folders by greater than or equal to time of latest update. Can be used with updatedAtLte to create a range.
        :type updated_at_gte: datetime
        :param name: Search for folders containing the specified name.
        :type name: str
        :param path: Search folders by path.
        :type path: str
        :param parent_folder_ids: Search folders with the given parent folderId.
        :type parent_folder_ids: list[int]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseFolder, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            "properties",
            "after",
            "before",
            "limit",
            "sort",
            "ids",
            "id_lte",
            "id_gte",
            "created_at",
            "created_at_lte",
            "created_at_gte",
            "updated_at",
            "updated_at_lte",
            "updated_at_gte",
            "name",
            "path",
            "parent_folder_ids",
        ]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method do_search" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("before") is not None:  # noqa: E501
            query_params.append(("before", local_var_params["before"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("sort") is not None:  # noqa: E501
            query_params.append(("sort", local_var_params["sort"]))  # noqa: E501
            collection_formats["sort"] = "multi"  # noqa: E501
        if local_var_params.get("ids") is not None:  # noqa: E501
            query_params.append(("ids", local_var_params["ids"]))  # noqa: E501
            collection_formats["ids"] = "multi"  # noqa: E501
        if local_var_params.get("id_lte") is not None:  # noqa: E501
            query_params.append(("idLte", local_var_params["id_lte"]))  # noqa: E501
        if local_var_params.get("id_gte") is not None:  # noqa: E501
            query_params.append(("idGte", local_var_params["id_gte"]))  # noqa: E501
        if local_var_params.get("created_at") is not None:  # noqa: E501
            query_params.append(("createdAt", local_var_params["created_at"]))  # noqa: E501
        if local_var_params.get("created_at_lte") is not None:  # noqa: E501
            query_params.append(("createdAtLte", local_var_params["created_at_lte"]))  # noqa: E501
        if local_var_params.get("created_at_gte") is not None:  # noqa: E501
            query_params.append(("createdAtGte", local_var_params["created_at_gte"]))  # noqa: E501
        if local_var_params.get("updated_at") is not None:  # noqa: E501
            query_params.append(("updatedAt", local_var_params["updated_at"]))  # noqa: E501
        if local_var_params.get("updated_at_lte") is not None:  # noqa: E501
            query_params.append(("updatedAtLte", local_var_params["updated_at_lte"]))  # noqa: E501
        if local_var_params.get("updated_at_gte") is not None:  # noqa: E501
            query_params.append(("updatedAtGte", local_var_params["updated_at_gte"]))  # noqa: E501
        if local_var_params.get("name") is not None:  # noqa: E501
            query_params.append(("name", local_var_params["name"]))  # noqa: E501
        if local_var_params.get("path") is not None:  # noqa: E501
            query_params.append(("path", local_var_params["path"]))  # noqa: E501
        if local_var_params.get("parent_folder_ids") is not None:  # noqa: E501
            query_params.append(("parentFolderIds", local_var_params["parent_folder_ids"]))  # noqa: E501
            collection_formats["parentFolderIds"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseFolder",
        }

        return self.api_client.call_api(
            "/files/v3/folders/search",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, folder_id, **kwargs):  # noqa: E501
        """Retrieve folder by ID  # noqa: E501

        Retrieve a folder by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of desired folder (required)
        :type folder_id: str
        :param properties: Properties to set on returned folder.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Folder
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(folder_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, folder_id, **kwargs):  # noqa: E501
        """Retrieve folder by ID  # noqa: E501

        Retrieve a folder by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(folder_id, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of desired folder (required)
        :type folder_id: str
        :param properties: Properties to set on returned folder.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Folder, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_id", "properties"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `get_by_id`")  # noqa: E501

        if self.api_client.client_side_validation and "folder_id" in local_var_params and not re.search(r"\d+", local_var_params["folder_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `folder_id` when calling `get_by_id`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "Folder",
        }

        return self.api_client.call_api(
            "/files/v3/folders/{folderId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_path(self, folder_path, **kwargs):  # noqa: E501
        """Retrieve folder by path  # noqa: E501

        Retrieve a folder, identified by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_path(folder_path, async_req=True)
        >>> result = thread.get()

        :param folder_path: Path of desired folder. (required)
        :type folder_path: str
        :param properties: Properties to set on returned folder.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Folder
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_path_with_http_info(folder_path, **kwargs)  # noqa: E501

    def get_by_path_with_http_info(self, folder_path, **kwargs):  # noqa: E501
        """Retrieve folder by path  # noqa: E501

        Retrieve a folder, identified by its path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_path_with_http_info(folder_path, async_req=True)
        >>> result = thread.get()

        :param folder_path: Path of desired folder. (required)
        :type folder_path: str
        :param properties: Properties to set on returned folder.
        :type properties: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Folder, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_path", "properties"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_path" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_path' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_path") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_path` when calling `get_by_path`")  # noqa: E501

        if self.api_client.client_side_validation and "folder_path" in local_var_params and not re.search(r".+", local_var_params["folder_path"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `folder_path` when calling `get_by_path`, must conform to the pattern `/.+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "folder_path" in local_var_params:
            path_params["folderPath"] = local_var_params["folder_path"]  # noqa: E501

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "Folder",
        }

        return self.api_client.call_api(
            "/files/v3/folders/{folderPath}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_properties(self, folder_id, folder_update_input, **kwargs):  # noqa: E501
        """Update folder properties by folder ID  # noqa: E501

        Update a folder's properties, identified by folder ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties(folder_id, folder_update_input, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of folder to update (required)
        :type folder_id: str
        :param folder_update_input: (required)
        :type folder_update_input: FolderUpdateInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Folder
        """
        kwargs["_return_http_data_only"] = True
        return self.update_properties_with_http_info(folder_id, folder_update_input, **kwargs)  # noqa: E501

    def update_properties_with_http_info(self, folder_id, folder_update_input, **kwargs):  # noqa: E501
        """Update folder properties by folder ID  # noqa: E501

        Update a folder's properties, identified by folder ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties_with_http_info(folder_id, folder_update_input, async_req=True)
        >>> result = thread.get()

        :param folder_id: ID of folder to update (required)
        :type folder_id: str
        :param folder_update_input: (required)
        :type folder_update_input: FolderUpdateInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Folder, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_id", "folder_update_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_properties" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_id` when calling `update_properties`")  # noqa: E501
        # verify the required parameter 'folder_update_input' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_update_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_update_input` when calling `update_properties`")  # noqa: E501

        if self.api_client.client_side_validation and "folder_id" in local_var_params and not re.search(r"\d+", local_var_params["folder_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `folder_id` when calling `update_properties`, must conform to the pattern `/\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "folder_id" in local_var_params:
            path_params["folderId"] = local_var_params["folder_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "folder_update_input" in local_var_params:
            body_params = local_var_params["folder_update_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "Folder",
        }

        return self.api_client.call_api(
            "/files/v3/folders/{folderId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_properties_recursively(self, folder_update_input_with_id, **kwargs):  # noqa: E501
        """Update folder properties  # noqa: E501

        Update properties of folder by given ID. This action happens asynchronously and will update all of the folder's children as well.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties_recursively(folder_update_input_with_id, async_req=True)
        >>> result = thread.get()

        :param folder_update_input_with_id: (required)
        :type folder_update_input_with_id: FolderUpdateInputWithId
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: FolderUpdateTaskLocator
        """
        kwargs["_return_http_data_only"] = True
        return self.update_properties_recursively_with_http_info(folder_update_input_with_id, **kwargs)  # noqa: E501

    def update_properties_recursively_with_http_info(self, folder_update_input_with_id, **kwargs):  # noqa: E501
        """Update folder properties  # noqa: E501

        Update properties of folder by given ID. This action happens asynchronously and will update all of the folder's children as well.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_properties_recursively_with_http_info(folder_update_input_with_id, async_req=True)
        >>> result = thread.get()

        :param folder_update_input_with_id: (required)
        :type folder_update_input_with_id: FolderUpdateInputWithId
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(FolderUpdateTaskLocator, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["folder_update_input_with_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_properties_recursively" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'folder_update_input_with_id' is set
        if self.api_client.client_side_validation and local_var_params.get("folder_update_input_with_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `folder_update_input_with_id` when calling `update_properties_recursively`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "folder_update_input_with_id" in local_var_params:
            body_params = local_var_params["folder_update_input_with_id"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            202: "FolderUpdateTaskLocator",
        }

        return self.api_client.call_api(
            "/files/v3/folders/update/async",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.webhooks.api.settings_api import SettingsApi
from hubspot.webhooks.api.subscriptions_api import SubscriptionsApi



# coding: utf-8

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.pipelines.configuration import Configuration


class PipelinePatchInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"archived": "bool", "display_order": "int", "label": "str"}

    attribute_map = {"archived": "archived", "display_order": "displayOrder", "label": "label"}

    def __init__(self, archived=None, display_order=None, label=None, local_vars_configuration=None):  # noqa: E501
        """PipelinePatchInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._archived = None
        self._display_order = None
        self._label = None
        self.discriminator = None

        if archived is not None:
            self.archived = archived
        if display_order is not None:
            self.display_order = display_order
        if label is not None:
            self.label = label

    @property
    def archived(self):
        """Gets the archived of this PipelinePatchInput.  # noqa: E501

        Whether the pipeline is archived. This property should only be provided when restoring an archived pipeline. If it's provided in any other call, the request will fail and a `400 Bad Request` will be returned.  # noqa: E501

        :return: The archived of this PipelinePatchInput.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this PipelinePatchInput.

        Whether the pipeline is archived. This property should only be provided when restoring an archived pipeline. If it's provided in any other call, the request will fail and a `400 Bad Request` will be returned.  # noqa: E501

        :param archived: The archived of this PipelinePatchInput.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def display_order(self):
        """Gets the display_order of this PipelinePatchInput.  # noqa: E501

        The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :return: The display_order of this PipelinePatchInput.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this PipelinePatchInput.

        The order for displaying this pipeline. If two pipelines have a matching `displayOrder`, they will be sorted alphabetically by label.  # noqa: E501

        :param display_order: The display_order of this PipelinePatchInput.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def label(self):
        """Gets the label of this PipelinePatchInput.  # noqa: E501

        A unique label used to organize pipelines in HubSpot's UI  # noqa: E501

        :return: The label of this PipelinePatchInput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this PipelinePatchInput.

        A unique label used to organize pipelines in HubSpot's UI  # noqa: E501

        :param label: The label of this PipelinePatchInput.  # noqa: E501
        :type label: str
        """

        self._label = label

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipelinePatchInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PipelinePatchInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class TimelineEventTemplateCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"detail_template": "str", "name": "str", "tokens": "list[TimelineEventTemplateToken]", "header_template": "str", "object_type": "str"}

    attribute_map = {"detail_template": "detailTemplate", "name": "name", "tokens": "tokens", "header_template": "headerTemplate", "object_type": "objectType"}

    def __init__(self, detail_template=None, name=None, tokens=None, header_template=None, object_type=None, local_vars_configuration=None):  # noqa: E501
        """TimelineEventTemplateCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._detail_template = None
        self._name = None
        self._tokens = None
        self._header_template = None
        self._object_type = None
        self.discriminator = None

        if detail_template is not None:
            self.detail_template = detail_template
        self.name = name
        self.tokens = tokens
        if header_template is not None:
            self.header_template = header_template
        self.object_type = object_type

    @property
    def detail_template(self):
        """Gets the detail_template of this TimelineEventTemplateCreateRequest.  # noqa: E501

        This uses Markdown syntax with Handlebars and event-specific data to render HTML on a timeline when you expand the details.  # noqa: E501

        :return: The detail_template of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._detail_template

    @detail_template.setter
    def detail_template(self, detail_template):
        """Sets the detail_template of this TimelineEventTemplateCreateRequest.

        This uses Markdown syntax with Handlebars and event-specific data to render HTML on a timeline when you expand the details.  # noqa: E501

        :param detail_template: The detail_template of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :type detail_template: str
        """

        self._detail_template = detail_template

    @property
    def name(self):
        """Gets the name of this TimelineEventTemplateCreateRequest.  # noqa: E501

        The template name.  # noqa: E501

        :return: The name of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TimelineEventTemplateCreateRequest.

        The template name.  # noqa: E501

        :param name: The name of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def tokens(self):
        """Gets the tokens of this TimelineEventTemplateCreateRequest.  # noqa: E501

        A collection of tokens that can be used as custom properties on the event and to create fully fledged CRM objects.  # noqa: E501

        :return: The tokens of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :rtype: list[TimelineEventTemplateToken]
        """
        return self._tokens

    @tokens.setter
    def tokens(self, tokens):
        """Sets the tokens of this TimelineEventTemplateCreateRequest.

        A collection of tokens that can be used as custom properties on the event and to create fully fledged CRM objects.  # noqa: E501

        :param tokens: The tokens of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :type tokens: list[TimelineEventTemplateToken]
        """
        if self.local_vars_configuration.client_side_validation and tokens is None:  # noqa: E501
            raise ValueError("Invalid value for `tokens`, must not be `None`")  # noqa: E501

        self._tokens = tokens

    @property
    def header_template(self):
        """Gets the header_template of this TimelineEventTemplateCreateRequest.  # noqa: E501

        This uses Markdown syntax with Handlebars and event-specific data to render HTML on a timeline as a header.  # noqa: E501

        :return: The header_template of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._header_template

    @header_template.setter
    def header_template(self, header_template):
        """Sets the header_template of this TimelineEventTemplateCreateRequest.

        This uses Markdown syntax with Handlebars and event-specific data to render HTML on a timeline as a header.  # noqa: E501

        :param header_template: The header_template of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :type header_template: str
        """

        self._header_template = header_template

    @property
    def object_type(self):
        """Gets the object_type of this TimelineEventTemplateCreateRequest.  # noqa: E501

        The type of CRM object this template is for. [Contacts, companies, tickets, and deals] are supported.  # noqa: E501

        :return: The object_type of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this TimelineEventTemplateCreateRequest.

        The type of CRM object this template is for. [Contacts, companies, tickets, and deals] are supported.  # noqa: E501

        :param object_type: The object_type of this TimelineEventTemplateCreateRequest.  # noqa: E501
        :type object_type: str
        """
        if self.local_vars_configuration.client_side_validation and object_type is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type`, must not be `None`")  # noqa: E501

        self._object_type = object_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimelineEventTemplateCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TimelineEventTemplateCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.automation.actions as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def callbacks_api(self) -> api_client.CallbacksApi:
        return self._configure_api_client(api_client, "CallbacksApi")

    @property
    def definitions_api(self) -> api_client.DefinitionsApi:
        return self._configure_api_client(api_client, "DefinitionsApi")

    @property
    def functions_api(self) -> api_client.FunctionsApi:
        return self._configure_api_client(api_client, "FunctionsApi")

    @property
    def revisions_api(self) -> api_client.RevisionsApi:
        return self._configure_api_client(api_client, "RevisionsApi")



# coding: utf-8

# flake8: noqa
"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.marketing.forms.models.collection_response_form_definition_base_forward_paging import CollectionResponseFormDefinitionBaseForwardPaging
from hubspot.marketing.forms.models.collection_response_form_definition_base_forward_paging_results_inner import CollectionResponseFormDefinitionBaseForwardPagingResultsInner
from hubspot.marketing.forms.models.datepicker_field import DatepickerField
from hubspot.marketing.forms.models.dependent_field import DependentField
from hubspot.marketing.forms.models.dependent_field_dependent_field import DependentFieldDependentField
from hubspot.marketing.forms.models.dependent_field_filter import DependentFieldFilter
from hubspot.marketing.forms.models.dropdown_field import DropdownField
from hubspot.marketing.forms.models.email_field import EmailField
from hubspot.marketing.forms.models.email_field_validation import EmailFieldValidation
from hubspot.marketing.forms.models.enumerated_field_option import EnumeratedFieldOption
from hubspot.marketing.forms.models.error import Error
from hubspot.marketing.forms.models.error_detail import ErrorDetail
from hubspot.marketing.forms.models.field_group import FieldGroup
from hubspot.marketing.forms.models.file_field import FileField
from hubspot.marketing.forms.models.form_definition_base import FormDefinitionBase
from hubspot.marketing.forms.models.form_definition_create_request_base import FormDefinitionCreateRequestBase
from hubspot.marketing.forms.models.form_display_options import FormDisplayOptions
from hubspot.marketing.forms.models.form_post_submit_action import FormPostSubmitAction
from hubspot.marketing.forms.models.form_style import FormStyle
from hubspot.marketing.forms.models.forward_paging import ForwardPaging
from hubspot.marketing.forms.models.hub_spot_form_configuration import HubSpotFormConfiguration
from hubspot.marketing.forms.models.hub_spot_form_definition import HubSpotFormDefinition
from hubspot.marketing.forms.models.hub_spot_form_definition_all_of import HubSpotFormDefinitionAllOf
from hubspot.marketing.forms.models.hub_spot_form_definition_all_of_legal_consent_options import HubSpotFormDefinitionAllOfLegalConsentOptions
from hubspot.marketing.forms.models.hub_spot_form_definition_create_request import HubSpotFormDefinitionCreateRequest
from hubspot.marketing.forms.models.hub_spot_form_definition_create_request_all_of import HubSpotFormDefinitionCreateRequestAllOf
from hubspot.marketing.forms.models.hub_spot_form_definition_patch_request import HubSpotFormDefinitionPatchRequest
from hubspot.marketing.forms.models.legal_consent_checkbox import LegalConsentCheckbox
from hubspot.marketing.forms.models.legal_consent_options_explicit_consent_to_process import LegalConsentOptionsExplicitConsentToProcess
from hubspot.marketing.forms.models.legal_consent_options_implicit_consent_to_process import LegalConsentOptionsImplicitConsentToProcess
from hubspot.marketing.forms.models.legal_consent_options_legitimate_interest import LegalConsentOptionsLegitimateInterest
from hubspot.marketing.forms.models.legal_consent_options_none import LegalConsentOptionsNone
from hubspot.marketing.forms.models.lifecycle_stage import LifecycleStage
from hubspot.marketing.forms.models.mobile_phone_field import MobilePhoneField
from hubspot.marketing.forms.models.multi_line_text_field import MultiLineTextField
from hubspot.marketing.forms.models.multiple_checkboxes_field import MultipleCheckboxesField
from hubspot.marketing.forms.models.next_page import NextPage
from hubspot.marketing.forms.models.number_field import NumberField
from hubspot.marketing.forms.models.number_field_validation import NumberFieldValidation
from hubspot.marketing.forms.models.payment_link_radio_field import PaymentLinkRadioField
from hubspot.marketing.forms.models.phone_field import PhoneField
from hubspot.marketing.forms.models.phone_field_validation import PhoneFieldValidation
from hubspot.marketing.forms.models.radio_field import RadioField
from hubspot.marketing.forms.models.single_checkbox_field import SingleCheckboxField
from hubspot.marketing.forms.models.single_line_text_field import SingleLineTextField



# coding: utf-8

# flake8: noqa
"""
    Video Conferencing Extension

    These APIs allow you to specify URLs that can be used to interact with a video conferencing application, to allow HubSpot to add video conference links to meeting requests with contacts.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.extensions.videoconferencing.models.error import Error
from hubspot.crm.extensions.videoconferencing.models.error_detail import ErrorDetail
from hubspot.crm.extensions.videoconferencing.models.external_settings import ExternalSettings



# coding: utf-8

# flake8: noqa
"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.lists.models.api_collection_response_join_time_and_record_id import ApiCollectionResponseJoinTimeAndRecordId
from hubspot.crm.lists.models.api_collection_response_record_list_membership_no_paging import ApiCollectionResponseRecordListMembershipNoPaging
from hubspot.crm.lists.models.error import Error
from hubspot.crm.lists.models.error_detail import ErrorDetail
from hubspot.crm.lists.models.join_time_and_record_id import JoinTimeAndRecordId
from hubspot.crm.lists.models.list_create_request import ListCreateRequest
from hubspot.crm.lists.models.list_create_response import ListCreateResponse
from hubspot.crm.lists.models.list_fetch_response import ListFetchResponse
from hubspot.crm.lists.models.list_filter_update_request import ListFilterUpdateRequest
from hubspot.crm.lists.models.list_folder_create_request import ListFolderCreateRequest
from hubspot.crm.lists.models.list_folder_create_response import ListFolderCreateResponse
from hubspot.crm.lists.models.list_folder_fetch_response import ListFolderFetchResponse
from hubspot.crm.lists.models.list_move_request import ListMoveRequest
from hubspot.crm.lists.models.list_search_request import ListSearchRequest
from hubspot.crm.lists.models.list_search_response import ListSearchResponse
from hubspot.crm.lists.models.list_update_response import ListUpdateResponse
from hubspot.crm.lists.models.lists_by_id_response import ListsByIdResponse
from hubspot.crm.lists.models.membership_change_request import MembershipChangeRequest
from hubspot.crm.lists.models.memberships_update_response import MembershipsUpdateResponse
from hubspot.crm.lists.models.next_page import NextPage
from hubspot.crm.lists.models.paging import Paging
from hubspot.crm.lists.models.previous_page import PreviousPage
from hubspot.crm.lists.models.public_absolute_comparative_timestamp_refine_by import PublicAbsoluteComparativeTimestampRefineBy
from hubspot.crm.lists.models.public_absolute_ranged_timestamp_refine_by import PublicAbsoluteRangedTimestampRefineBy
from hubspot.crm.lists.models.public_ads_search_filter import PublicAdsSearchFilter
from hubspot.crm.lists.models.public_ads_time_filter import PublicAdsTimeFilter
from hubspot.crm.lists.models.public_all_history_refine_by import PublicAllHistoryRefineBy
from hubspot.crm.lists.models.public_all_property_types_operation import PublicAllPropertyTypesOperation
from hubspot.crm.lists.models.public_and_filter_branch import PublicAndFilterBranch
from hubspot.crm.lists.models.public_association_filter_branch import PublicAssociationFilterBranch
from hubspot.crm.lists.models.public_association_in_list_filter import PublicAssociationInListFilter
from hubspot.crm.lists.models.public_batch_migration_mapping import PublicBatchMigrationMapping
from hubspot.crm.lists.models.public_bool_property_operation import PublicBoolPropertyOperation
from hubspot.crm.lists.models.public_calendar_date_property_operation import PublicCalendarDatePropertyOperation
from hubspot.crm.lists.models.public_campaign_influenced_filter import PublicCampaignInfluencedFilter
from hubspot.crm.lists.models.public_communication_subscription_filter import PublicCommunicationSubscriptionFilter
from hubspot.crm.lists.models.public_comparative_date_property_operation import PublicComparativeDatePropertyOperation
from hubspot.crm.lists.models.public_comparative_property_updated_operation import PublicComparativePropertyUpdatedOperation
from hubspot.crm.lists.models.public_constant_filter import PublicConstantFilter
from hubspot.crm.lists.models.public_cta_analytics_filter import PublicCtaAnalyticsFilter
from hubspot.crm.lists.models.public_date_point import PublicDatePoint
from hubspot.crm.lists.models.public_date_property_operation import PublicDatePropertyOperation
from hubspot.crm.lists.models.public_date_time_property_operation import PublicDateTimePropertyOperation
from hubspot.crm.lists.models.public_email_event_filter import PublicEmailEventFilter
from hubspot.crm.lists.models.public_email_subscription_filter import PublicEmailSubscriptionFilter
from hubspot.crm.lists.models.public_enumeration_property_operation import PublicEnumerationPropertyOperation
from hubspot.crm.lists.models.public_event_analytics_filter import PublicEventAnalyticsFilter
from hubspot.crm.lists.models.public_event_filter_metadata import PublicEventFilterMetadata
from hubspot.crm.lists.models.public_fiscal_quarter_reference import PublicFiscalQuarterReference
from hubspot.crm.lists.models.public_fiscal_year_reference import PublicFiscalYearReference
from hubspot.crm.lists.models.public_form_submission_filter import PublicFormSubmissionFilter
from hubspot.crm.lists.models.public_form_submission_filter_coalescing_refine_by import PublicFormSubmissionFilterCoalescingRefineBy
from hubspot.crm.lists.models.public_form_submission_on_page_filter import PublicFormSubmissionOnPageFilter
from hubspot.crm.lists.models.public_in_list_filter import PublicInListFilter
from hubspot.crm.lists.models.public_in_list_filter_metadata import PublicInListFilterMetadata
from hubspot.crm.lists.models.public_index_offset import PublicIndexOffset
from hubspot.crm.lists.models.public_indexed_time_point import PublicIndexedTimePoint
from hubspot.crm.lists.models.public_indexed_time_point_index_reference import PublicIndexedTimePointIndexReference
from hubspot.crm.lists.models.public_integration_event_filter import PublicIntegrationEventFilter
from hubspot.crm.lists.models.public_list_folder import PublicListFolder
from hubspot.crm.lists.models.public_migration_mapping import PublicMigrationMapping
from hubspot.crm.lists.models.public_month_reference import PublicMonthReference
from hubspot.crm.lists.models.public_multi_string_property_operation import PublicMultiStringPropertyOperation
from hubspot.crm.lists.models.public_not_all_filter_branch import PublicNotAllFilterBranch
from hubspot.crm.lists.models.public_not_any_filter_branch import PublicNotAnyFilterBranch
from hubspot.crm.lists.models.public_now_reference import PublicNowReference
from hubspot.crm.lists.models.public_num_associations_filter import PublicNumAssociationsFilter
from hubspot.crm.lists.models.public_num_occurrences_refine_by import PublicNumOccurrencesRefineBy
from hubspot.crm.lists.models.public_number_property_operation import PublicNumberPropertyOperation
from hubspot.crm.lists.models.public_object_list import PublicObjectList
from hubspot.crm.lists.models.public_object_list_search_result import PublicObjectListSearchResult
from hubspot.crm.lists.models.public_or_filter_branch import PublicOrFilterBranch
from hubspot.crm.lists.models.public_page_view_analytics_filter import PublicPageViewAnalyticsFilter
from hubspot.crm.lists.models.public_privacy_analytics_filter import PublicPrivacyAnalyticsFilter
from hubspot.crm.lists.models.public_property_association_filter_branch import PublicPropertyAssociationFilterBranch
from hubspot.crm.lists.models.public_property_association_filter_branch_filter_branches_inner import PublicPropertyAssociationFilterBranchFilterBranchesInner
from hubspot.crm.lists.models.public_property_association_filter_branch_filters_inner import PublicPropertyAssociationFilterBranchFiltersInner
from hubspot.crm.lists.models.public_property_association_in_list_filter import PublicPropertyAssociationInListFilter
from hubspot.crm.lists.models.public_property_filter import PublicPropertyFilter
from hubspot.crm.lists.models.public_property_referenced_time import PublicPropertyReferencedTime
from hubspot.crm.lists.models.public_quarter_reference import PublicQuarterReference
from hubspot.crm.lists.models.public_ranged_date_property_operation import PublicRangedDatePropertyOperation
from hubspot.crm.lists.models.public_ranged_number_property_operation import PublicRangedNumberPropertyOperation
from hubspot.crm.lists.models.public_ranged_time_operation import PublicRangedTimeOperation
from hubspot.crm.lists.models.public_relative_comparative_timestamp_refine_by import PublicRelativeComparativeTimestampRefineBy
from hubspot.crm.lists.models.public_relative_ranged_timestamp_refine_by import PublicRelativeRangedTimestampRefineBy
from hubspot.crm.lists.models.public_restricted_filter_branch import PublicRestrictedFilterBranch
from hubspot.crm.lists.models.public_rolling_date_range_property_operation import PublicRollingDateRangePropertyOperation
from hubspot.crm.lists.models.public_rolling_property_updated_operation import PublicRollingPropertyUpdatedOperation
from hubspot.crm.lists.models.public_set_occurrences_refine_by import PublicSetOccurrencesRefineBy
from hubspot.crm.lists.models.public_string_property_operation import PublicStringPropertyOperation
from hubspot.crm.lists.models.public_survey_monkey_filter import PublicSurveyMonkeyFilter
from hubspot.crm.lists.models.public_survey_monkey_value_filter import PublicSurveyMonkeyValueFilter
from hubspot.crm.lists.models.public_survey_monkey_value_filter_value_comparison import PublicSurveyMonkeyValueFilterValueComparison
from hubspot.crm.lists.models.public_time_offset import PublicTimeOffset
from hubspot.crm.lists.models.public_time_point_operation import PublicTimePointOperation
from hubspot.crm.lists.models.public_time_point_operation_time_point import PublicTimePointOperationTimePoint
from hubspot.crm.lists.models.public_today_reference import PublicTodayReference
from hubspot.crm.lists.models.public_unified_events_filter import PublicUnifiedEventsFilter
from hubspot.crm.lists.models.public_unified_events_filter_branch import PublicUnifiedEventsFilterBranch
from hubspot.crm.lists.models.public_webinar_filter import PublicWebinarFilter
from hubspot.crm.lists.models.public_week_reference import PublicWeekReference
from hubspot.crm.lists.models.public_year_reference import PublicYearReference
from hubspot.crm.lists.models.record_list_membership import RecordListMembership



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicEventAnalyticsFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "event_id": "str",
        "coalescing_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "pruning_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "filter_type": "str",
        "operator": "str",
    }

    attribute_map = {"event_id": "eventId", "coalescing_refine_by": "coalescingRefineBy", "pruning_refine_by": "pruningRefineBy", "filter_type": "filterType", "operator": "operator"}

    def __init__(self, event_id=None, coalescing_refine_by=None, pruning_refine_by=None, filter_type="EVENT", operator=None, local_vars_configuration=None):  # noqa: E501
        """PublicEventAnalyticsFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._event_id = None
        self._coalescing_refine_by = None
        self._pruning_refine_by = None
        self._filter_type = None
        self._operator = None
        self.discriminator = None

        self.event_id = event_id
        if coalescing_refine_by is not None:
            self.coalescing_refine_by = coalescing_refine_by
        if pruning_refine_by is not None:
            self.pruning_refine_by = pruning_refine_by
        self.filter_type = filter_type
        self.operator = operator

    @property
    def event_id(self):
        """Gets the event_id of this PublicEventAnalyticsFilter.  # noqa: E501


        :return: The event_id of this PublicEventAnalyticsFilter.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this PublicEventAnalyticsFilter.


        :param event_id: The event_id of this PublicEventAnalyticsFilter.  # noqa: E501
        :type event_id: str
        """
        if self.local_vars_configuration.client_side_validation and event_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def coalescing_refine_by(self):
        """Gets the coalescing_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501


        :return: The coalescing_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._coalescing_refine_by

    @coalescing_refine_by.setter
    def coalescing_refine_by(self, coalescing_refine_by):
        """Sets the coalescing_refine_by of this PublicEventAnalyticsFilter.


        :param coalescing_refine_by: The coalescing_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501
        :type coalescing_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._coalescing_refine_by = coalescing_refine_by

    @property
    def pruning_refine_by(self):
        """Gets the pruning_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501


        :return: The pruning_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._pruning_refine_by

    @pruning_refine_by.setter
    def pruning_refine_by(self, pruning_refine_by):
        """Sets the pruning_refine_by of this PublicEventAnalyticsFilter.


        :param pruning_refine_by: The pruning_refine_by of this PublicEventAnalyticsFilter.  # noqa: E501
        :type pruning_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._pruning_refine_by = pruning_refine_by

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicEventAnalyticsFilter.  # noqa: E501


        :return: The filter_type of this PublicEventAnalyticsFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicEventAnalyticsFilter.


        :param filter_type: The filter_type of this PublicEventAnalyticsFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["EVENT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def operator(self):
        """Gets the operator of this PublicEventAnalyticsFilter.  # noqa: E501


        :return: The operator of this PublicEventAnalyticsFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicEventAnalyticsFilter.


        :param operator: The operator of this PublicEventAnalyticsFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEventAnalyticsFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEventAnalyticsFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class Filter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"high_value": "str", "property_name": "str", "values": "list[str]", "value": "str", "operator": "str"}

    attribute_map = {"high_value": "highValue", "property_name": "propertyName", "values": "values", "value": "value", "operator": "operator"}

    def __init__(self, high_value=None, property_name=None, values=None, value=None, operator=None, local_vars_configuration=None):  # noqa: E501
        """Filter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._high_value = None
        self._property_name = None
        self._values = None
        self._value = None
        self._operator = None
        self.discriminator = None

        if high_value is not None:
            self.high_value = high_value
        self.property_name = property_name
        if values is not None:
            self.values = values
        if value is not None:
            self.value = value
        self.operator = operator

    @property
    def high_value(self):
        """Gets the high_value of this Filter.  # noqa: E501


        :return: The high_value of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._high_value

    @high_value.setter
    def high_value(self, high_value):
        """Sets the high_value of this Filter.


        :param high_value: The high_value of this Filter.  # noqa: E501
        :type high_value: str
        """

        self._high_value = high_value

    @property
    def property_name(self):
        """Gets the property_name of this Filter.  # noqa: E501


        :return: The property_name of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this Filter.


        :param property_name: The property_name of this Filter.  # noqa: E501
        :type property_name: str
        """
        if self.local_vars_configuration.client_side_validation and property_name is None:  # noqa: E501
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def values(self):
        """Gets the values of this Filter.  # noqa: E501


        :return: The values of this Filter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this Filter.


        :param values: The values of this Filter.  # noqa: E501
        :type values: list[str]
        """

        self._values = values

    @property
    def value(self):
        """Gets the value of this Filter.  # noqa: E501


        :return: The value of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Filter.


        :param value: The value of this Filter.  # noqa: E501
        :type value: str
        """

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this Filter.  # noqa: E501

        null  # noqa: E501

        :return: The operator of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this Filter.

        null  # noqa: E501

        :param operator: The operator of this Filter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `operator` ({0}), must be one of {1}".format(operator, allowed_values))  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Filter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Filter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicEmailToDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "contact_ils_lists": "PublicEmailRecipients",
        "limit_send_frequency": "bool",
        "suppress_graymail": "bool",
        "contact_ids": "PublicEmailRecipients",
        "contact_lists": "PublicEmailRecipients",
    }

    attribute_map = {
        "contact_ils_lists": "contactIlsLists",
        "limit_send_frequency": "limitSendFrequency",
        "suppress_graymail": "suppressGraymail",
        "contact_ids": "contactIds",
        "contact_lists": "contactLists",
    }

    def __init__(self, contact_ils_lists=None, limit_send_frequency=None, suppress_graymail=None, contact_ids=None, contact_lists=None, local_vars_configuration=None):  # noqa: E501
        """PublicEmailToDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._contact_ils_lists = None
        self._limit_send_frequency = None
        self._suppress_graymail = None
        self._contact_ids = None
        self._contact_lists = None
        self.discriminator = None

        if contact_ils_lists is not None:
            self.contact_ils_lists = contact_ils_lists
        if limit_send_frequency is not None:
            self.limit_send_frequency = limit_send_frequency
        if suppress_graymail is not None:
            self.suppress_graymail = suppress_graymail
        if contact_ids is not None:
            self.contact_ids = contact_ids
        if contact_lists is not None:
            self.contact_lists = contact_lists

    @property
    def contact_ils_lists(self):
        """Gets the contact_ils_lists of this PublicEmailToDetails.  # noqa: E501


        :return: The contact_ils_lists of this PublicEmailToDetails.  # noqa: E501
        :rtype: PublicEmailRecipients
        """
        return self._contact_ils_lists

    @contact_ils_lists.setter
    def contact_ils_lists(self, contact_ils_lists):
        """Sets the contact_ils_lists of this PublicEmailToDetails.


        :param contact_ils_lists: The contact_ils_lists of this PublicEmailToDetails.  # noqa: E501
        :type contact_ils_lists: PublicEmailRecipients
        """

        self._contact_ils_lists = contact_ils_lists

    @property
    def limit_send_frequency(self):
        """Gets the limit_send_frequency of this PublicEmailToDetails.  # noqa: E501

          # noqa: E501

        :return: The limit_send_frequency of this PublicEmailToDetails.  # noqa: E501
        :rtype: bool
        """
        return self._limit_send_frequency

    @limit_send_frequency.setter
    def limit_send_frequency(self, limit_send_frequency):
        """Sets the limit_send_frequency of this PublicEmailToDetails.

          # noqa: E501

        :param limit_send_frequency: The limit_send_frequency of this PublicEmailToDetails.  # noqa: E501
        :type limit_send_frequency: bool
        """

        self._limit_send_frequency = limit_send_frequency

    @property
    def suppress_graymail(self):
        """Gets the suppress_graymail of this PublicEmailToDetails.  # noqa: E501

          # noqa: E501

        :return: The suppress_graymail of this PublicEmailToDetails.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_graymail

    @suppress_graymail.setter
    def suppress_graymail(self, suppress_graymail):
        """Sets the suppress_graymail of this PublicEmailToDetails.

          # noqa: E501

        :param suppress_graymail: The suppress_graymail of this PublicEmailToDetails.  # noqa: E501
        :type suppress_graymail: bool
        """

        self._suppress_graymail = suppress_graymail

    @property
    def contact_ids(self):
        """Gets the contact_ids of this PublicEmailToDetails.  # noqa: E501


        :return: The contact_ids of this PublicEmailToDetails.  # noqa: E501
        :rtype: PublicEmailRecipients
        """
        return self._contact_ids

    @contact_ids.setter
    def contact_ids(self, contact_ids):
        """Sets the contact_ids of this PublicEmailToDetails.


        :param contact_ids: The contact_ids of this PublicEmailToDetails.  # noqa: E501
        :type contact_ids: PublicEmailRecipients
        """

        self._contact_ids = contact_ids

    @property
    def contact_lists(self):
        """Gets the contact_lists of this PublicEmailToDetails.  # noqa: E501


        :return: The contact_lists of this PublicEmailToDetails.  # noqa: E501
        :rtype: PublicEmailRecipients
        """
        return self._contact_lists

    @contact_lists.setter
    def contact_lists(self, contact_lists):
        """Sets the contact_lists of this PublicEmailToDetails.


        :param contact_lists: The contact_lists of this PublicEmailToDetails.  # noqa: E501
        :type contact_lists: PublicEmailRecipients
        """

        self._contact_lists = contact_lists

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailToDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailToDetails):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.automation.actions.api.callbacks_api import CallbacksApi
from hubspot.automation.actions.api.definitions_api import DefinitionsApi
from hubspot.automation.actions.api.functions_api import FunctionsApi
from hubspot.automation.actions.api.revisions_api import RevisionsApi



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class HubSpotFormDefinitionAllOfLegalConsentOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "type": "str",
        "subscription_type_ids": "list[int]",
        "lawful_basis": "str",
        "privacy_text": "str",
        "communications_checkboxes": "list[LegalConsentCheckbox]",
        "communication_consent_text": "str",
        "consent_to_process_checkbox_label": "str",
        "consent_to_process_footer_text": "str",
        "consent_to_process_text": "str",
    }

    attribute_map = {
        "type": "type",
        "subscription_type_ids": "subscriptionTypeIds",
        "lawful_basis": "lawfulBasis",
        "privacy_text": "privacyText",
        "communications_checkboxes": "communicationsCheckboxes",
        "communication_consent_text": "communicationConsentText",
        "consent_to_process_checkbox_label": "consentToProcessCheckboxLabel",
        "consent_to_process_footer_text": "consentToProcessFooterText",
        "consent_to_process_text": "consentToProcessText",
    }

    def __init__(
        self,
        type="implicit_consent_to_process",
        subscription_type_ids=None,
        lawful_basis=None,
        privacy_text=None,
        communications_checkboxes=None,
        communication_consent_text=None,
        consent_to_process_checkbox_label=None,
        consent_to_process_footer_text=None,
        consent_to_process_text=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HubSpotFormDefinitionAllOfLegalConsentOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._subscription_type_ids = None
        self._lawful_basis = None
        self._privacy_text = None
        self._communications_checkboxes = None
        self._communication_consent_text = None
        self._consent_to_process_checkbox_label = None
        self._consent_to_process_footer_text = None
        self._consent_to_process_text = None
        self.discriminator = None

        self.type = type
        self.subscription_type_ids = subscription_type_ids
        self.lawful_basis = lawful_basis
        self.privacy_text = privacy_text
        self.communications_checkboxes = communications_checkboxes
        if communication_consent_text is not None:
            self.communication_consent_text = communication_consent_text
        if consent_to_process_checkbox_label is not None:
            self.consent_to_process_checkbox_label = consent_to_process_checkbox_label
        if consent_to_process_footer_text is not None:
            self.consent_to_process_footer_text = consent_to_process_footer_text
        if consent_to_process_text is not None:
            self.consent_to_process_text = consent_to_process_text

    @property
    def type(self):
        """Gets the type of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The type of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param type: The type of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["implicit_consent_to_process"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def subscription_type_ids(self):
        """Gets the subscription_type_ids of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The subscription_type_ids of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: list[int]
        """
        return self._subscription_type_ids

    @subscription_type_ids.setter
    def subscription_type_ids(self, subscription_type_ids):
        """Sets the subscription_type_ids of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param subscription_type_ids: The subscription_type_ids of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type subscription_type_ids: list[int]
        """
        if self.local_vars_configuration.client_side_validation and subscription_type_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `subscription_type_ids`, must not be `None`")  # noqa: E501

        self._subscription_type_ids = subscription_type_ids

    @property
    def lawful_basis(self):
        """Gets the lawful_basis of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The lawful_basis of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._lawful_basis

    @lawful_basis.setter
    def lawful_basis(self, lawful_basis):
        """Sets the lawful_basis of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param lawful_basis: The lawful_basis of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type lawful_basis: str
        """
        if self.local_vars_configuration.client_side_validation and lawful_basis is None:  # noqa: E501
            raise ValueError("Invalid value for `lawful_basis`, must not be `None`")  # noqa: E501
        allowed_values = ["lead", "client", "other"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and lawful_basis not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `lawful_basis` ({0}), must be one of {1}".format(lawful_basis, allowed_values))  # noqa: E501

        self._lawful_basis = lawful_basis

    @property
    def privacy_text(self):
        """Gets the privacy_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The privacy_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._privacy_text

    @privacy_text.setter
    def privacy_text(self, privacy_text):
        """Sets the privacy_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param privacy_text: The privacy_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type privacy_text: str
        """
        if self.local_vars_configuration.client_side_validation and privacy_text is None:  # noqa: E501
            raise ValueError("Invalid value for `privacy_text`, must not be `None`")  # noqa: E501

        self._privacy_text = privacy_text

    @property
    def communications_checkboxes(self):
        """Gets the communications_checkboxes of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The communications_checkboxes of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: list[LegalConsentCheckbox]
        """
        return self._communications_checkboxes

    @communications_checkboxes.setter
    def communications_checkboxes(self, communications_checkboxes):
        """Sets the communications_checkboxes of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param communications_checkboxes: The communications_checkboxes of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type communications_checkboxes: list[LegalConsentCheckbox]
        """
        if self.local_vars_configuration.client_side_validation and communications_checkboxes is None:  # noqa: E501
            raise ValueError("Invalid value for `communications_checkboxes`, must not be `None`")  # noqa: E501

        self._communications_checkboxes = communications_checkboxes

    @property
    def communication_consent_text(self):
        """Gets the communication_consent_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The communication_consent_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._communication_consent_text

    @communication_consent_text.setter
    def communication_consent_text(self, communication_consent_text):
        """Sets the communication_consent_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param communication_consent_text: The communication_consent_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type communication_consent_text: str
        """

        self._communication_consent_text = communication_consent_text

    @property
    def consent_to_process_checkbox_label(self):
        """Gets the consent_to_process_checkbox_label of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The consent_to_process_checkbox_label of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._consent_to_process_checkbox_label

    @consent_to_process_checkbox_label.setter
    def consent_to_process_checkbox_label(self, consent_to_process_checkbox_label):
        """Sets the consent_to_process_checkbox_label of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param consent_to_process_checkbox_label: The consent_to_process_checkbox_label of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type consent_to_process_checkbox_label: str
        """

        self._consent_to_process_checkbox_label = consent_to_process_checkbox_label

    @property
    def consent_to_process_footer_text(self):
        """Gets the consent_to_process_footer_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The consent_to_process_footer_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._consent_to_process_footer_text

    @consent_to_process_footer_text.setter
    def consent_to_process_footer_text(self, consent_to_process_footer_text):
        """Sets the consent_to_process_footer_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param consent_to_process_footer_text: The consent_to_process_footer_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type consent_to_process_footer_text: str
        """

        self._consent_to_process_footer_text = consent_to_process_footer_text

    @property
    def consent_to_process_text(self):
        """Gets the consent_to_process_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501

          # noqa: E501

        :return: The consent_to_process_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :rtype: str
        """
        return self._consent_to_process_text

    @consent_to_process_text.setter
    def consent_to_process_text(self, consent_to_process_text):
        """Sets the consent_to_process_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.

          # noqa: E501

        :param consent_to_process_text: The consent_to_process_text of this HubSpotFormDefinitionAllOfLegalConsentOptions.  # noqa: E501
        :type consent_to_process_text: str
        """

        self._consent_to_process_text = consent_to_process_text

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubSpotFormDefinitionAllOfLegalConsentOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubSpotFormDefinitionAllOfLegalConsentOptions):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.cms.domains as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def domains_api(self) -> api_client.DomainsApi:
        return self._configure_api_client(api_client, "DomainsApi")



import hubspot.crm.associations.schema as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):

    @property
    def types_api(self) -> api_client.TypesApi:
        return self._configure_api_client(api_client, "TypesApi")




import hubspot.crm.extensions.cards as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def cards_api(self) -> api_client.CardsApi:
        return self._configure_api_client(api_client, "CardsApi")

    @property
    def sample_response_api(self) -> api_client.SampleResponseApi:
        return self._configure_api_client(api_client, "SampleResponseApi")



# coding: utf-8

"""
    Contacts

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.contacts.configuration import Configuration


class PublicObjectSearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"query": "str", "limit": "int", "after": "str", "sorts": "list[str]", "properties": "list[str]", "filter_groups": "list[FilterGroup]"}

    attribute_map = {"query": "query", "limit": "limit", "after": "after", "sorts": "sorts", "properties": "properties", "filter_groups": "filterGroups"}

    def __init__(self, query=None, limit=None, after=None, sorts=None, properties=None, filter_groups=None, local_vars_configuration=None):  # noqa: E501
        """PublicObjectSearchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._query = None
        self._limit = None
        self._after = None
        self._sorts = None
        self._properties = None
        self._filter_groups = None
        self.discriminator = None

        if query is not None:
            self.query = query
        if limit is not None:
            self.limit = limit
        if after is not None:
            self.after = after
        if sorts is not None:
            self.sorts = sorts
        if properties is not None:
            self.properties = properties
        if filter_groups is not None:
            self.filter_groups = filter_groups

    @property
    def query(self):
        """Gets the query of this PublicObjectSearchRequest.  # noqa: E501


        :return: The query of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this PublicObjectSearchRequest.


        :param query: The query of this PublicObjectSearchRequest.  # noqa: E501
        :type query: str
        """

        self._query = query

    @property
    def limit(self):
        """Gets the limit of this PublicObjectSearchRequest.  # noqa: E501


        :return: The limit of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this PublicObjectSearchRequest.


        :param limit: The limit of this PublicObjectSearchRequest.  # noqa: E501
        :type limit: int
        """

        self._limit = limit

    @property
    def after(self):
        """Gets the after of this PublicObjectSearchRequest.  # noqa: E501


        :return: The after of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._after

    @after.setter
    def after(self, after):
        """Sets the after of this PublicObjectSearchRequest.


        :param after: The after of this PublicObjectSearchRequest.  # noqa: E501
        :type after: str
        """

        self._after = after

    @property
    def sorts(self):
        """Gets the sorts of this PublicObjectSearchRequest.  # noqa: E501


        :return: The sorts of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._sorts

    @sorts.setter
    def sorts(self, sorts):
        """Sets the sorts of this PublicObjectSearchRequest.


        :param sorts: The sorts of this PublicObjectSearchRequest.  # noqa: E501
        :type sorts: list[str]
        """

        self._sorts = sorts

    @property
    def properties(self):
        """Gets the properties of this PublicObjectSearchRequest.  # noqa: E501


        :return: The properties of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this PublicObjectSearchRequest.


        :param properties: The properties of this PublicObjectSearchRequest.  # noqa: E501
        :type properties: list[str]
        """

        self._properties = properties

    @property
    def filter_groups(self):
        """Gets the filter_groups of this PublicObjectSearchRequest.  # noqa: E501


        :return: The filter_groups of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[FilterGroup]
        """
        return self._filter_groups

    @filter_groups.setter
    def filter_groups(self, filter_groups):
        """Sets the filter_groups of this PublicObjectSearchRequest.


        :param filter_groups: The filter_groups of this PublicObjectSearchRequest.  # noqa: E501
        :type filter_groups: list[FilterGroup]
        """

        self._filter_groups = filter_groups

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicObjectSearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicObjectSearchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.cards.configuration import Configuration


class CardAuditResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"action_type": "str", "object_type_id": "int", "auth_source": "str", "changed_at": "int", "application_id": "int", "initiating_user_id": "int"}

    attribute_map = {
        "action_type": "actionType",
        "object_type_id": "objectTypeId",
        "auth_source": "authSource",
        "changed_at": "changedAt",
        "application_id": "applicationId",
        "initiating_user_id": "initiatingUserId",
    }

    def __init__(self, action_type=None, object_type_id=None, auth_source=None, changed_at=None, application_id=None, initiating_user_id=None, local_vars_configuration=None):  # noqa: E501
        """CardAuditResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._action_type = None
        self._object_type_id = None
        self._auth_source = None
        self._changed_at = None
        self._application_id = None
        self._initiating_user_id = None
        self.discriminator = None

        self.action_type = action_type
        self.object_type_id = object_type_id
        self.auth_source = auth_source
        self.changed_at = changed_at
        self.application_id = application_id
        self.initiating_user_id = initiating_user_id

    @property
    def action_type(self):
        """Gets the action_type of this CardAuditResponse.  # noqa: E501


        :return: The action_type of this CardAuditResponse.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this CardAuditResponse.


        :param action_type: The action_type of this CardAuditResponse.  # noqa: E501
        :type action_type: str
        """
        if self.local_vars_configuration.client_side_validation and action_type is None:  # noqa: E501
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CREATE", "UPDATE", "DELETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `action_type` ({0}), must be one of {1}".format(action_type, allowed_values))  # noqa: E501

        self._action_type = action_type

    @property
    def object_type_id(self):
        """Gets the object_type_id of this CardAuditResponse.  # noqa: E501


        :return: The object_type_id of this CardAuditResponse.  # noqa: E501
        :rtype: int
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this CardAuditResponse.


        :param object_type_id: The object_type_id of this CardAuditResponse.  # noqa: E501
        :type object_type_id: int
        """
        if self.local_vars_configuration.client_side_validation and object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type_id`, must not be `None`")  # noqa: E501

        self._object_type_id = object_type_id

    @property
    def auth_source(self):
        """Gets the auth_source of this CardAuditResponse.  # noqa: E501


        :return: The auth_source of this CardAuditResponse.  # noqa: E501
        :rtype: str
        """
        return self._auth_source

    @auth_source.setter
    def auth_source(self, auth_source):
        """Sets the auth_source of this CardAuditResponse.


        :param auth_source: The auth_source of this CardAuditResponse.  # noqa: E501
        :type auth_source: str
        """
        if self.local_vars_configuration.client_side_validation and auth_source is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_source`, must not be `None`")  # noqa: E501
        allowed_values = ["INTERNAL", "APP", "EXTERNAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and auth_source not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `auth_source` ({0}), must be one of {1}".format(auth_source, allowed_values))  # noqa: E501

        self._auth_source = auth_source

    @property
    def changed_at(self):
        """Gets the changed_at of this CardAuditResponse.  # noqa: E501


        :return: The changed_at of this CardAuditResponse.  # noqa: E501
        :rtype: int
        """
        return self._changed_at

    @changed_at.setter
    def changed_at(self, changed_at):
        """Sets the changed_at of this CardAuditResponse.


        :param changed_at: The changed_at of this CardAuditResponse.  # noqa: E501
        :type changed_at: int
        """
        if self.local_vars_configuration.client_side_validation and changed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `changed_at`, must not be `None`")  # noqa: E501

        self._changed_at = changed_at

    @property
    def application_id(self):
        """Gets the application_id of this CardAuditResponse.  # noqa: E501


        :return: The application_id of this CardAuditResponse.  # noqa: E501
        :rtype: int
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this CardAuditResponse.


        :param application_id: The application_id of this CardAuditResponse.  # noqa: E501
        :type application_id: int
        """
        if self.local_vars_configuration.client_side_validation and application_id is None:  # noqa: E501
            raise ValueError("Invalid value for `application_id`, must not be `None`")  # noqa: E501

        self._application_id = application_id

    @property
    def initiating_user_id(self):
        """Gets the initiating_user_id of this CardAuditResponse.  # noqa: E501


        :return: The initiating_user_id of this CardAuditResponse.  # noqa: E501
        :rtype: int
        """
        return self._initiating_user_id

    @initiating_user_id.setter
    def initiating_user_id(self, initiating_user_id):
        """Sets the initiating_user_id of this CardAuditResponse.


        :param initiating_user_id: The initiating_user_id of this CardAuditResponse.  # noqa: E501
        :type initiating_user_id: int
        """
        if self.local_vars_configuration.client_side_validation and initiating_user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `initiating_user_id`, must not be `None`")  # noqa: E501

        self._initiating_user_id = initiating_user_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CardAuditResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CardAuditResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Auth Oauth

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.oauth.configuration import Configuration


class TokenResponseIF(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"access_token": "str", "refresh_token": "str", "id_token": "str", "token_type": "str", "expires_in": "int"}

    attribute_map = {"access_token": "access_token", "refresh_token": "refresh_token", "id_token": "id_token", "token_type": "token_type", "expires_in": "expires_in"}

    def __init__(self, access_token=None, refresh_token=None, id_token=None, token_type=None, expires_in=None, local_vars_configuration=None):  # noqa: E501
        """TokenResponseIF - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._refresh_token = None
        self._id_token = None
        self._token_type = None
        self._expires_in = None
        self.discriminator = None

        self.access_token = access_token
        self.refresh_token = refresh_token
        if id_token is not None:
            self.id_token = id_token
        self.token_type = token_type
        self.expires_in = expires_in

    @property
    def access_token(self):
        """Gets the access_token of this TokenResponseIF.  # noqa: E501

          # noqa: E501

        :return: The access_token of this TokenResponseIF.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this TokenResponseIF.

          # noqa: E501

        :param access_token: The access_token of this TokenResponseIF.  # noqa: E501
        :type access_token: str
        """
        if self.local_vars_configuration.client_side_validation and access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `access_token`, must not be `None`")  # noqa: E501

        self._access_token = access_token

    @property
    def refresh_token(self):
        """Gets the refresh_token of this TokenResponseIF.  # noqa: E501

          # noqa: E501

        :return: The refresh_token of this TokenResponseIF.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this TokenResponseIF.

          # noqa: E501

        :param refresh_token: The refresh_token of this TokenResponseIF.  # noqa: E501
        :type refresh_token: str
        """
        if self.local_vars_configuration.client_side_validation and refresh_token is None:  # noqa: E501
            raise ValueError("Invalid value for `refresh_token`, must not be `None`")  # noqa: E501

        self._refresh_token = refresh_token

    @property
    def id_token(self):
        """Gets the id_token of this TokenResponseIF.  # noqa: E501

          # noqa: E501

        :return: The id_token of this TokenResponseIF.  # noqa: E501
        :rtype: str
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this TokenResponseIF.

          # noqa: E501

        :param id_token: The id_token of this TokenResponseIF.  # noqa: E501
        :type id_token: str
        """

        self._id_token = id_token

    @property
    def token_type(self):
        """Gets the token_type of this TokenResponseIF.  # noqa: E501

          # noqa: E501

        :return: The token_type of this TokenResponseIF.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this TokenResponseIF.

          # noqa: E501

        :param token_type: The token_type of this TokenResponseIF.  # noqa: E501
        :type token_type: str
        """
        if self.local_vars_configuration.client_side_validation and token_type is None:  # noqa: E501
            raise ValueError("Invalid value for `token_type`, must not be `None`")  # noqa: E501

        self._token_type = token_type

    @property
    def expires_in(self):
        """Gets the expires_in of this TokenResponseIF.  # noqa: E501

          # noqa: E501

        :return: The expires_in of this TokenResponseIF.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this TokenResponseIF.

          # noqa: E501

        :param expires_in: The expires_in of this TokenResponseIF.  # noqa: E501
        :type expires_in: int
        """
        if self.local_vars_configuration.client_side_validation and expires_in is None:  # noqa: E501
            raise ValueError("Invalid value for `expires_in`, must not be `None`")  # noqa: E501

        self._expires_in = expires_in

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenResponseIF):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TokenResponseIF):
            return True

        return self.to_dict() != other.to_dict()
